@@ -1,4 +1,4 @@
-qsim.norm <-
+qsimplex.norm <-
 function (p, mu, sig) {
 	return(mu + qnorm(p) * sig * sqrt(mu^3 * (1-mu)^3))
 }
